aboutsummaryrefslogtreecommitdiff
path: root/examples/sound/cdstream/stream.h
diff options
context:
space:
mode:
authorspicyjpeg <thatspicyjpeg@gmail.com>2023-06-20 13:27:34 +0200
committerspicyjpeg <thatspicyjpeg@gmail.com>2023-06-20 13:27:34 +0200
commit79a966486615e60be3a37d278945dc3dd0fd933b (patch)
tree4a4cd8412c10b9646ff1966af964a314c0567005 /examples/sound/cdstream/stream.h
parentced21c69f7b399dce169069334c1424e5254d582 (diff)
downloadpsn00bsdk-79a966486615e60be3a37d278945dc3dd0fd933b.tar.gz
More SPU streaming example tweaks
Diffstat (limited to 'examples/sound/cdstream/stream.h')
-rw-r--r--examples/sound/cdstream/stream.h12
1 files changed, 8 insertions, 4 deletions
diff --git a/examples/sound/cdstream/stream.h b/examples/sound/cdstream/stream.h
index 15e3ec3..aa384ed 100644
--- a/examples/sound/cdstream/stream.h
+++ b/examples/sound/cdstream/stream.h
@@ -121,16 +121,20 @@ void Stream_Destroy(Stream_Context *ctx);
/**
* @brief Starts playback of a stream.
*
* @details Activates the given stream context and starts playing audio from its
* FIFO. This function must be called while no other stream is active and after
* the stream's FIFO has been filled up.
*
* @param ctx
+ * @param resume Should be true if resuming a previously stopped stream
* @return True if the stream was started, false if another stream is active
*
* @see Stream_Stop()
*/
-bool Stream_Start(Stream_Context *ctx);
+bool Stream_Start(Stream_Context *ctx, bool resume);
/**
* @brief Stops playback of any currently active stream.
@@ -121,16 +121,20 @@ void Stream_Destroy(Stream_Context *ctx);
* @brief Starts playback of a stream.
*
- * @details Activates the given stream context and starts playing audio from its
- * FIFO. This function must be called while no other stream is active and after
- * the stream's FIFO has been filled up.
+ * @details Activates the given stream context and starts or resumes playing
+ * audio from its FIFO. This function must be called while no other stream is
+ * active and after the stream's FIFO has been filled up. In order to prevent
+ * skipping, the resume argument shall be set to true if the stream was
+ * previously stopped and its buffer in SPU RAM was not overwritten by another
+ * stream or sample data.
*
* @param ctx